@@ -1,51 +1,61 @@
 package Dancer2::Plugin::Ajax;
 # ABSTRACT: a plugin for adding Ajax route handlers
-$Dancer2::Plugin::Ajax::VERSION = '0.200001';
+$Dancer2::Plugin::Ajax::VERSION = '0.300000';
 use strict;
 use warnings;
+use Dancer2::Core::Types 'Str';
 use Dancer2::Plugin;
 
-register 'ajax' => sub {
-    my ( $dsl, $pattern, @rest ) = @_;
+has content_type => (
+    is => 'ro',
+    isa => Str,
+    from_config => sub { 'text/xml' },
+);
 
-    my $default_methods = [ 'get', 'post' ];
+plugin_keywords 'ajax';
 
-    # If the given pattern is an ArrayRef, we override the defaults
-    # and pass these onto to DSL->any()
+sub ajax {
+    my ( $plugin, $pattern, @rest ) = @_;
+
+    my @default_methods = ( 'get', 'post' );
+
+    # If the given pattern is an ArrayRef, we override the default methods
     if( ref($pattern) eq "ARRAY" ) {
-        $default_methods = $pattern;
+        @default_methods = @$pattern;
         $pattern = shift(@rest);
     }
 
     my $code;
     for my $e (@rest) { $code = $e if ( ref($e) eq 'CODE' ) }
 
-    my $content_type = plugin_setting->{content_type} || 'text/xml';
-
     my $ajax_route = sub {
 
         # # must be an XMLHttpRequest
-        if ( not $dsl->app->request->is_ajax ) {
-            $dsl->pass and return 0;
+        if ( not $plugin->app->request->is_ajax ) {
+            $plugin->app->pass;
         }
 
         # Default response content type is either what's defined in the
         # plugin setting or text/xml
-        $dsl->response->header('Content-Type')
-          or $dsl->response->content_type( $content_type );
+        $plugin->app->response->header('Content-Type')
+          or $plugin->app->response->content_type( $plugin->content_type );
 
         # disable layout
-        my $layout = $dsl->setting('layout');
-        $dsl->setting( 'layout' => undef );
+        my $layout = $plugin->app->config->{'layout'};
+        $plugin->app->config->{'layout'} = undef;
         my $response = $code->();
-        $dsl->setting( 'layout' => $layout );
+        $plugin->app->config->{'layout'} = $layout;
         return $response;
     };
 
-    $dsl->any( $default_methods => $pattern, $ajax_route );
-};
-
-register_plugin;
+    foreach my $method ( @default_methods ) {
+        $plugin->app->add_route(
+            method => $method,
+            regexp => $pattern,
+            code   => $ajax_route,
+        );
+    }
+}
 
 1;
 
@@ -61,7 +71,7 @@ Dancer2::Plugin::Ajax - a plugin for adding Ajax route handlers
 
 =head1 VERSION
 
-version 0.200001
+version 0.300000
 
 =head1 SYNOPSIS
 
